@@ -24,14 +24,12 @@
 #include "gedit-output-window.h"
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <libintl.h>
 #include <string.h>
 
 #include "gconf-stock-icons.h"
 
-#define _(x) gettext (x)
-#define N_(x) (x)
-
 static void
 gconf_search_dialog_response (GtkDialog *dialog, gint response_id)
 {
@@ -70,33 +68,40 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 	GConfEditorWindow *window;
 	GdkCursor *cursor;
 
-	const gchar *pattern;
+	gchar *pattern;
 	int res;
 	
 	window = g_object_get_data (G_OBJECT (dialog), "editor-window");
 	gedit_output_window_clear (GEDIT_OUTPUT_WINDOW (window->output_window));
 	window->output_window_type = GCONF_EDITOR_WINDOW_OUTPUT_WINDOW_SEARCH;
 
-	pattern = gtk_entry_get_text (GTK_ENTRY (dialog->entry));
+	pattern = g_strdup (gtk_entry_get_text (GTK_ENTRY (dialog->entry)));
 
 	cursor = gdk_cursor_new (GDK_WATCH);
 	gdk_window_set_cursor (GTK_WIDGET (dialog)->window, cursor);
 	gdk_cursor_unref (cursor);
 	gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
 
+	g_object_add_weak_pointer (G_OBJECT (dialog), (gpointer)&dialog);
+
 	res = gconf_tree_model_build_match_list  (GCONF_TREE_MODEL (window->tree_model),
 						  GEDIT_OUTPUT_WINDOW (window->output_window), 
 						  pattern,
 						  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->search_in_keys)),
-						  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->search_in_values)));
+						  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->search_in_values)),
+						  G_OBJECT (dialog));
 
-	gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
-	gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
+	g_free (pattern);
 
-	if (res != 0) {
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	} else {
-		gconf_search_not_found_dialog(window);
+	if (dialog != NULL) {
+		gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
+		gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
+
+		if (res != 0) {
+			gtk_widget_destroy (GTK_WIDGET (dialog));
+		} else {
+			gconf_search_not_found_dialog(window);
+		}
 	}
 }
 
